@@ -45,14 +45,14 @@ class DomainDetailsHandler(BaseHandler):
         domain = Domain.get_domain_by_name(domain_name, self.db)
 
         if not domain:
-            self.set_status(404, 'Domain %s not found' % domain_name)
+            self.set_status(404, self._('Domain %s not found') % domain_name)
             return
 
         result = self.girl.get('domains_details')
         data = next((l for l in result if l['name'] == domain_name), None)
 
         if not data:
-            self.set_status(404, 'Domain %s not found' % domain_name)
+            self.set_status(404, self._('Domain %s not found') % domain_name)
             return
 
         page_count = data.get('pageCount', 0)
@@ -123,33 +123,21 @@ class DomainReviewsHandler(BaseHandler):
             self.set_status(404, 'Domain %s not found' % domain_name)
             return
 
-        reviews = domain.get_active_reviews(
-            self.db,
-            url_starts_with=term,
+        reviews = yield self.application.search_provider.get_domain_active_reviews(
+            domain=domain,
             current_page=current_page,
-            page_size=page_size
+            page_size=page_size,
+            page_filter=term,
         )
 
-        if term:
-            review_count = None
-        else:
-            review_count = yield self.cache.get_active_review_count(domain)
+        if 'reviewsCount' not in reviews:
+            if not term:
+                reviews['reviewsCount'] = yield self.cache.get_active_review_count(domain)
+            else:
+                reviews['reviewsCount'] = None
 
-        result = {
-            'reviewsCount': review_count,
-            'pages': [],
-        }
-
-        for page in reviews:
-            result['pages'].append({
-                "url": page.url,
-                "uuid": str(page.uuid),
-                "violationCount": page.violations_count,
-                "completedAt": page.last_review_date,
-                "reviewId": str(page.last_review_uuid)
-            })
-
-        self.write_json(result)
+        self.write_json(reviews)
+        self.finish()
 
 
 class DomainGroupedViolationsHandler(BaseHandler):
