@@ -17,7 +17,7 @@ class PageHandler(BaseHandler):
         page = Page.by_uuid(uuid, self.db)
 
         if not page:
-            self.set_status(404, 'Page UUID [%s] not found' % uuid)
+            self.set_status(404, self._('Page UUID [%s] not found') % uuid)
             return
 
         page_json = {
@@ -40,13 +40,14 @@ class PageHandler(BaseHandler):
             score,
             self.application.http_client.fetch,
             self.application.event_bus.publish,
-            self.application.config
+            self.application.config,
+            self.application.girl
         )
 
         created, url, result = result
 
         if not created and result['reason'] == 'invalid_url':
-            self.set_status(400, 'Invalid url [%s]' % url)
+            self.set_status(400, self._('Invalid url [%s]') % url)
             self.write_json({
                 'reason': 'invalid_url',
                 'url': url,
@@ -56,7 +57,7 @@ class PageHandler(BaseHandler):
             return
 
         if not created and result['reason'] == 'redirect':
-            self.set_status(400, 'Redirect URL [%s]' % url)
+            self.set_status(400, self._('Redirect URL [%s]') % url)
             self.write_json({
                 'reason': 'redirect',
                 'url': url,
@@ -76,7 +77,7 @@ class PageReviewsHandler(BaseHandler):
         page = Page.by_uuid(uuid, self.db)
 
         if not page:
-            self.set_status(404, 'Page UUID [%s] not found' % uuid)
+            self.set_status(404, self._('Page UUID [%s] not found') % uuid)
             return
 
         reviews = self.db.query(Review) \
@@ -101,7 +102,7 @@ class PageViolationsPerDayHandler(BaseHandler):
         page = Page.by_uuid(uuid, self.db)
 
         if not page:
-            self.set_status(404, 'Page UUID [%s] not found' % uuid)
+            self.set_status(404, self._('Page UUID [%s] not found') % uuid)
             return
 
         violations_per_day = page.get_violations_per_day(self.db)
