@@ -15,7 +15,15 @@ class MetaTagsValidator(Validator):
                     "No meta tags found on this page. This is damaging for "
                     "Search Engines."
                 ),
-                'category': 'HTTP'
+                'category': 'HTTP',
+                'generic_description': (
+                    'Validates the presence of metatags. They are important '
+                    'to inform metadata about the HTML document. '
+                    'The absent of metatags are damaging for search '
+                    'engines. Meta elements are typically used to specify page '
+                    'description, keywords, author of the document, last '
+                    'modified, and other metadata.'
+                )
             },
             'page.metatags.description_too_big': {
                 'title': 'Maximum size of description meta tag',
@@ -24,7 +32,13 @@ class MetaTagsValidator(Validator):
                     "It is best to keep meta descriptions shorter for better "
                     "indexing on Search engines."
                 ) % value['max_size'],
-                'category': 'SEO'
+                'category': 'SEO',
+                'generic_description': (
+                    'Validates the size of a description metatag. It is best to '
+                    'keep meta descriptions shorter for better indexing on '
+                    'search engines. This limit is configurable by Holmes '
+                    'Configuration.'
+                )
             }
         }
 
