@@ -115,6 +115,9 @@ class HolmesWorker(BaseWorker):
         self.error_handlers = [handler(self.config) for handler in self.load_error_handlers()]
 
         self.connect_sqlalchemy()
+
+        self.search_provider = self.load_search_provider()(self.config, self.db)
+
         self.connect_to_redis()
         self.start_otto()
 
@@ -131,6 +134,8 @@ class HolmesWorker(BaseWorker):
 
         self._insert_keys(self.violation_definitions)
 
+        self.configure_material_girl()
+
     def config_parser(self, parser):
         parser.add_argument(
             '--concurrency',
@@ -218,12 +223,14 @@ class HolmesWorker(BaseWorker):
                 config=self.config,
                 validators=self.validators,
                 facters=self.facters,
+                search_provider=self.search_provider,
                 async_get=self.async_get,
                 wait=self.otto.wait,
                 wait_timeout=0,  # max time to wait for all requests to finish
                 db=self.db,
                 cache=self.cache,
                 publish=self.publish,
+                girl=self.girl,
                 fact_definitions=self.fact_definitions,
                 violation_definitions=self.violation_definitions
             )
